# Conditional for release and snapshot builds. Uncomment for release-builds.
%global rel_build 1

# This is needed, because src-url contains branched part of versioning-scheme.
%global branch 1.23

# Settings used for build from snapshots.
%{!?rel_build:%global commit ac3768e41c6cdbbec5a27e05b7aed8a1cb375c8e}
%{!?rel_build:%global commit_date 20151003}
%{!?rel_build:%global shortcommit %(c=%{commit};echo ${c:0:7})}
%{!?rel_build:%global git_ver git%{commit_date}-%{shortcommit}}
%{!?rel_build:%global git_rel .git%{commit_date}.%{shortcommit}}
%{!?rel_build:%global git_tar %{name}-%{version}-%{git_ver}.tar.xz}

Name:          mate-control-center
Version:       %{branch}.3
%if 0%{?rel_build}
Release:       1%{?dist}
%else
Release:       10.2%{?git_rel}%{?dist}
%endif
Summary:       MATE Desktop control-center
License:       LGPLv2+ and GPLv2+
URL:           http://mate-desktop.org

# for downloading the tarball use 'spectool -g -R mate-control-center.spec'
# Source for release-builds.
%{?rel_build:Source0:     http://pub.mate-desktop.org/releases/%{branch}/%{name}-%{version}.tar.xz}
# Source for snapshot-builds.
%{!?rel_build:Source0:    http://git.mate-desktop.org/%{name}/snapshot/%{name}-%{commit}.tar.xz#/%{git_tar}}

BuildRequires: accountsservice-devel
BuildRequires: dconf-devel
BuildRequires: desktop-file-utils
BuildRequires: gtk3-devel
BuildRequires: libcanberra-devel
BuildRequires: libmatekbd-devel
BuildRequires: librsvg2-devel
BuildRequires: libSM-devel
BuildRequires: libXScrnSaver-devel
BuildRequires: mate-common
BuildRequires: mate-desktop-devel
BuildRequires: mate-menus-devel
BuildRequires: mate-settings-daemon-devel
BuildRequires: marco-devel
BuildRequires: polkit-devel

Requires: gsettings-desktop-schemas
# rhbz (#1234438)
Requires: mate-settings-daemon
# keyring support
Requires: gnome-keyring
Requires: %{name}-filesystem%{?_isa} = %{version}-%{release}


%description 
MATE Control Center configures system settings such as themes,
keyboards shortcuts, etc.

%package filesystem
Summary:      MATE Control Center directories
# NOTE: this is an "inverse dep" subpackage. It gets pulled in
# NOTE: by the main package an MUST not depend on the main package

%description filesystem
The MATE control-center provides a number of extension points
for applications. This package contains directories where applications
can install configuration files that are picked up by the control-center
utilities.

%package devel
Summary:      Development files for mate-settings-daemon
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
Development files for mate-control-center


%prep
%if 0%{?rel_build}
%autosetup -p1
%else
%autosetup -n %{name}-%{commit} -p1
%endif

%if 0%{?rel_build}
#NOCONFIGURE=1 ./autogen.sh
%else # 0%{?rel_build}
# needed for git snapshots
NOCONFIGURE=1 ./autogen.sh
%endif # 0%{?rel_build}

%build
%configure                           \
           --disable-static          \
           --disable-schemas-compile \
           --disable-update-mimedb

# remove unused-direct-shlib-dependency
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

make %{?_smp_mflags} V=1


%install
%{make_install}

find %{buildroot} -name '*.la' -exec rm -rf {} ';'
find %{buildroot} -name '*.a' -exec rm -rf {} ';'

desktop-file-install                                \
    --delete-original                               \
    --dir=%{buildroot}%{_datadir}/applications      \
%{buildroot}%{_datadir}/applications/*.desktop

# delete mime cache
rm %{buildroot}%{_datadir}/applications/mimeinfo.cache

%find_lang %{name} --with-gnome --all-name


%files -f %{name}.lang
%doc AUTHORS COPYING README
%config %{_sysconfdir}/xdg/menus/matecc.menu
%{_bindir}/mate-*
%{_libdir}/libmate-window-settings.so.*
%{_libdir}/window-manager-settings/
%{_libdir}/libmate-slab.so.*
%{_sbindir}/mate-display-properties-install-systemwide
%{_datadir}/applications/*.desktop
%{_datadir}/desktop-directories/matecc.directory
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/*/categories/*.png
%{_datadir}/icons/hicolor/scalable/apps/mate-*.svg
%{_datadir}/glib-2.0/schemas/org.mate.*.xml
%{_datadir}/mate-control-center/*
%{_datadir}/mate-time-admin/
%{_datadir}/mime/packages/mate-theme-package.xml
%{_datadir}/thumbnailers/mate-font-viewer.thumbnailer
%{_datadir}/polkit-1/actions/org.mate.randr.policy
%{_mandir}/man1/*.1.*

%files filesystem
%dir %{_datadir}/mate-control-center/
%dir %{_datadir}/mate-control-center/keybindings/

%files devel
%{_includedir}/mate-window-settings-2.0/
%{_includedir}/libmate-slab/
%{_libdir}/pkgconfig/mate-window-settings-2.0.pc
%{_libdir}/pkgconfig/mate-default-applications.pc
%{_libdir}/pkgconfig/mate-keybindings.pc
%{_libdir}/pkgconfig/mate-slab.pc
%{_libdir}/libmate-window-settings.so
%{_libdir}/libmate-slab.so


%changelog
* Sun Jan 19 2020 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.3-1
- update to 1.23.3

* Fri Aug 16 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.2-2
- test https://github.com/mate-desktop/mate-control-center/pull/495
- use https://github.com/mate-desktop/mate-control-center/commit/b670c37
- use https://github.com/mate-desktop/mate-control-center/commit/4f9ee9d
- use https://github.com/mate-desktop/mate-control-center/commit/0d3c306
- use https://github.com/mate-desktop/mate-control-center/commit/cacec3e
- test https://github.com/mate-desktop/mate-control-center/pull/502
- local test, support mimtype font collection
- test https://github.com/mate-desktop/mate-control-center/pull/503
- test https://github.com/mate-desktop/mate-control-center/commit/3e4ccaf
- test https://github.com/mate-desktop/mate-control-center/pull/506
- test https://github.com/mate-desktop/mate-control-center/pull/509
- use https://github.com/mate-desktop/mate-control-center/commit/d5f3167
- test https://github.com/mate-desktop/mate-control-center/pull/516
- test https://github.com/mate-desktop/mate-control-center/pull/517
- test https://github.com/mate-desktop/mate-control-center/pull/514
- test https://github.com/mate-desktop/mate-control-center/pull/520
- test https://github.com/mate-desktop/mate-control-center/pull/526
- test https://github.com/mate-desktop/mate-control-center/pull/522
- test https://github.com/mate-desktop/mate-control-center/commit/0734ed6
- test https://github.com/mate-desktop/mate-control-center/pull/525
- test https://github.com/mate-desktop/mate-control-center/pull/521
- test https://github.com/mate-desktop/mate-control-center/pull/523
- test https://github.com/mate-desktop/mate-control-center/pull/524

* Fri Aug 16 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.2-1
- update to  1.23.2

* Mon Jul 15 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.1-1
- update to 1.23.1

* Sat Jun 15 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.23.0-1
- update to 1.23.0
- build without libXxf86misc-devel

* Fri Apr 26 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.1-1
- update to 1.22.1

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.1-1
- update to 1.22.1 for better testing
- https://github.com/mate-desktop/mate-control-center/pull/429

* Mon Mar 04 2019 Wolfgang Ulbrich <fedora@raveit.de> - 1.22.0-1
- update to 1.22.0

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-2
- test https://github.com/mate-desktop/mate-control-center/pull/397
- test https://github.com/mate-desktop/mate-control-center/pull/398
- test https://github.com/mate-desktop/mate-control-center/pull/399
- test https://github.com/mate-desktop/mate-control-center/pull/408
- test https://github.com/mate-desktop/mate-control-center/pull/409
- test https://github.com/mate-desktop/mate-control-center/pull/404

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.2-1
- test 1.21.2

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.1-2
- test https://github.com/mate-desktop/mate-control-center/pull/362
- test https://github.com/mate-desktop/mate-control-center/pull/372
- test https://github.com/mate-desktop/mate-control-center/pull/374
- test https://github.com/mate-desktop/mate-control-center/commit/99f6f32
- test https://github.com/mate-desktop/mate-control-center/pull/380
- test https://github.com/mate-desktop/mate-control-center/pull/371
- test https://github.com/mate-desktop/mate-control-center/pull/382
- test https://github.com/mate-desktop/mate-control-center/pull/388
- test https://github.com/mate-desktop/mate-control-center/pull/391
- test https://github.com/mate-desktop/mate-control-center/pull/393
- test https://github.com/mate-desktop/mate-control-center/pull/392
- test https://github.com/mate-desktop/mate-control-center/pull/387
- test https://github.com/mate-desktop/mate-control-center/commit/ee42ad7
- test https://github.com/mate-desktop/mate-control-center/pull/395
- test https://github.com/mate-desktop/mate-control-center/pull/396

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.1-1
- test 1.21.1 tarball needed for new immages for pull 370
- test https://github.com/mate-desktop/mate-control-center/pull/370

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-2
- use new upstream patches
- test https://github.com/mate-desktop/mate-control-center/pull/362
- test https://github.com/mate-desktop/mate-control-center/pull/363
- test https://github.com/mate-desktop/mate-control-center/pull/369

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.21.0-1
- test 1.21.0 with mate-menus API change

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.2-4
- use normal mate-menus
- test https://github.com/mate-desktop/mate-control-center/pull/352

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.2-3
- test https://github.com/mate-desktop/mate-control-center/pull/344
- requires new mate-menus
- test https://github.com/mate-desktop/mate-control-center/pull/347
- local test, add css name

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.2-2
- use https://github.com/mate-desktop/mate-control-center/pull/327
- test https://github.com/mate-desktop/mate-control-center/pull/342

* Tue Mar 27 2018 Wolfgang Ulbrich <fedora@raveit.de> - 1.20.2-1
- update to 1.20.2

* Mon Feb 12 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-2
- test https://github.com/mate-desktop/mate-control-center/pull/326
- test https://github.com/mate-desktop/mate-control-center/pull/330
- test https://github.com/mate-desktop/mate-control-center/pull/327
- test https://github.com/mate-desktop/mate-control-center/pull/335
- test https://github.com/mate-desktop/mate-control-center/pull/336
- test https://github.com/mate-desktop/mate-control-center/pull/338
- test https://github.com/mate-desktop/mate-control-center/pull/340

* Mon Feb 12 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.20.0-1
- uppdate to 1.20.0
- drop mimeinfo rpm scriptlet
- drop desktop-database rpm scriptlet
- drop GSettings Schema rpm scriptlet
- drop IconCache rpm scriptlet
- switch to using autosetup

* Thu Jan 25 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.3-1
- update to  1.19.3
- test hdpi, https://github.com/mate-desktop/mate-control-center/pull/325

* Mon Jan 01 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.2-2
- test https://github.com/mate-desktop/mate-control-center/pull/317
- fix mate-window-properties
- test https://github.com/mate-desktop/mate-control-center/pull/318
- test https://github.com/mate-desktop/mate-control-center/commit/a34ea4d
- test https://github.com/mate-desktop/mate-control-center/pull/321
- test https://github.com/mate-desktop/mate-control-center/pull/323
- test hdpi, https://github.com/mate-desktop/mate-control-center/pull/325

* Mon Jan 01 2018 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.2-1
- update to 1.19.2

* Mon Dec 04 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.1-2
- test https://github.com/mate-desktop/mate-control-center/pull/302
- test https://github.com/mate-desktop/mate-control-center/pull/312
- test https://github.com/mate-desktop/mate-control-center/pull/313
- test https://github.com/mate-desktop/mate-control-center/pull/314
- test https://github.com/mate-desktop/mate-control-center/pull/309

* Tue Aug 15 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.19.1-1
- update to 1.19.1 release

* Tue Jul 04 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-2
- use https://github.com/mate-desktop/mate-control-center/pull/289
- warn about enabling multi-finger emulation, libinput may disables
- software buttons when clickfinger is enabled.
- test typing break
- test https://github.com/mate-desktop/mate-control-center/commit/5945276
- test https://github.com/mate-desktop/mate-control-center/pull/294
- test lhttps://github.com/mate-desktop/mate-control-center/pull/296
- test https://github.com/mate-desktop/mate-control-center/pull/297

* Wed Apr 05 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.19.0-1
- test 1.19.0

* Wed Apr 05 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.1-1
- test 1.18.1

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-2
- test https://github.com/mate-desktop/mate-control-center/commit/5473271
- test https://github.com/mate-desktop/mate-control-center/pull/275
- test https://github.com/mate-desktop/mate-control-center/pull/274

* Tue Mar 14 2017 Wolfgang Ulbrich <fedora@raveit.de> - 1.18.0-1
- update to 1.18.0 release

* Wed Jan 25 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.4-1
- test 1.17.4
- test fontviewer improvements
- test new deprecation fixes

* Wed Jan 25 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.3-2
- test new deprecation fixes

* Wed Jan 25 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.3-1
- test port to gtk_grid
- test 1.17.3 with fontviewer

* Wed Jan 25 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.2-2
- test port to gtk_grid

* Wed Jan 25 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.2-1
- update 1.17.2 to release with libinput support

* Tue Dec 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.1-1
- test 1.17.1 release

* Tue Dec 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.17.0-1
- update 1.17.0 release

* Thu Sep 22 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-1
- update to 1.16.0 release

* Sat Jul 02 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.2-2
- test https://github.com/mate-desktop/mate-control-center/pull/252

* Sat Jul 02 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.2-1
- test 1.15.2 release

* Sat Jul 02 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.1-1
- update to 1.15.1 release

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-2
- test color fixes

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.15.0-1
- test 1.15.0 release
- switch to gtk3

* Sat May 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-12
- add css style class appearance-window

* Wed Apr 06 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-11
- update to 1.14.0 release

* Sun Feb 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.2-12
- local usage

* Sun Feb 21 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.2-11
- update to 1.13.2 release

* Thu Feb 04 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-12
- local usage

* Thu Feb 04 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.1-11
- update to 1.13.1 release

* Sat Jan 16 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-12
- local usage

* Sat Jan 16 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.13.0-11
- update to 1.13.0

* Sun Dec 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-15
- local usage

* Sun Dec 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-14
- update keyring manager logic for epel7

* Sun Dec 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-13
- move mate-menus-preferences-category-menu to mate-menus

* Mon Dec 14 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-12
- local usage

* Mon Dec 14 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-11
- update to 1.12.1 release
- remove a upstreamed patch

* Fri Dec 04 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-13
- Obsoletes/Provides: mate-menus-preferences-category-menu (#1287845)

* Fri Nov 20 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-12
- fix a dangling pointer errors with mate-mouse-properties
- https://github.com/mate-desktop/mate-control-center/pull/205
- improve theme viewer, which avoid also a abrt alarm in f23
- https://github.com/mate-desktop/mate-control-center/pull/201

* Sat Oct 31 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.0-11
- update to 1.12.0 release
- include mate-preferences-categories.menu from mate-menus

* Fri Oct 09 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0.12
- for local usage

* Fri Oct 09 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0.11
- update to 1.11.0 release

* Tue Oct 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-10.2.git20151003.ac3768e
- for local usage

* Tue Oct 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.11.0-10.1.git20151003.ac3768e
- use git version from 2015-10-03

* Tue Aug 25 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.2.git20150803.0c8fd57
- improve font-viewer

* Thu Aug 06 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-10.1.git20150803.0c8fd57
- fix broken font preview in apperance-properties

* Mon Jul 13 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-11
- update to 1.10.1 release
- remove upstreamed patches

* Mon Jun 29 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-14
- fix font-viewer

* Wed Jun 24 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-13
- add runtime requires mate-settings-daemon
- fix rhbz (#1234438)

* Tue May 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-12
- GTK3, fixes unusable keyboard properties window

* Tue May 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.0-11
- update to 1.10.0 release
- removed upstreamed patch

* Thu Mar 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.90.11
- test, fix pkexec issue with m-c-c

* Thu Mar 05 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.90.10
- update to 1.9.90 release

* Tue Jan 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-10
- bump version to more than ten

* Tue Jan 20 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.1-1
- update to 1.9.1 release

* Sat Apr 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.9.0-1
- test, mate-1.9 with GTK3

* Sun Mar 16 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.1-1
- update to 1.8.1 release
- use wildcards for man files extensions
- remove --disable-scrollkeeper configure flag

* Wed Mar 05 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Wed Feb 19 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.90-1
- update to 1.7.90
- repair usage of git snapshots
- improve find language command for yelp-tools
- move autoreconf to the right place

* Thu Feb 13 2014 Dan Mashal <dan.mashal@fedoraproject.org> 1.7.0-2
- Add autoreconf to work around rpath.

* Sun Feb 09 2014 Dan Mashal <dan.mashal@fedoraproject.org> 1.7.0-1
- Update to 1.7.0 release.

* Sat Dec 21 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.0-0.2.git20131113.922d0e0
- make Maintainers life easier and use better git snapshot usage, Thanks to Björn Esser
- use BR marco-devel
- remove Obsoletes: libslab line, no need anymore
- fix mixed usage of tabs and spaces
- use modern 'make install' macro
- make configure command better readable

* Fri Dec 06 2013 Dan Mashal <dan.mashal@fedoraproject.org> 1.7.0-1.1.git922d0e0
- Update to 1.7.0
 
* Sat Oct 19 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-3
- switch to gnome-keyring for > f19

* Wed Jul 31 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-2
- add mate-control-center-file-system subpackage
- add requires hicolor-icon-theme

* Tue Jul 30 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1-1
- update to 1.6.1 release
- remove NOCONFIGURE=1 ./autogen.sh
- update file section
- remove old remnants from spec file

* Sat Jun 29 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.0-2
- add runtime require gsettings-desktop-schemas to have proxy support
- from gnome gsettings schema
- remove needless mate-control-center.convert file
- remove unused-direct-shlib-dependency to avoid rpmlint warnings
- cleanup BR's

* Wed Apr 03 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-1
- Update to latest 1.6.0 stable release.

* Mon Mar 25 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.5-3
- Readd desktop file install and remove desktop file validate
- Own proper dirs
- Use buildroot macro instead of rpm_build_root

* Mon Mar 25 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.5.5-2
- bump version in spec file

* Sun Mar 24 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.5.5-1
- update to new upstream release
- remove desktop-file-install command
- add desktop-file-validate command
- fix icon cache rpm scriptlet

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jan 17 2013 Rex Dieter <rdieter@fedoraproject.org> 1.5.3-3
- fix obsoletes
- sort BuildRequires

* Wed Jan 16 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-2
- Fix conflicts

* Tue Jan 15 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-1
- Update to latest upstream release.

* Fri Jan 11 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.2-2
- Switch back to old BR scheme.
- Drop unneeded BR's
- Add upstream patch to fix tielbar actions

* Fri Dec 21 2012 Nelson Marques <nmarques@fedoraproject.org> - 1.5.2-1
- Update to version 1.5.2 so we can receive mate-panel 1.5.3
- Remove dropped BRs: MateCORBA-2.0 
- Split out libslab (now distributed)
- Minor rework for readibility and ordered BuildRequires

* Sun Nov 25 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.1-1
- Bump to 1.5.1 release

* Thu Nov 08 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.0-2
- patch with latest upstream fixes

* Mon Oct 29 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.0-1
- update to 1.5.0 release
- change build requires and change style
- add requires gsettings-desktop-schemas
- add build requires gsettings-desktop-schemas-devel
- add schema scriptlets
- add build requires dconf-devel 

* Tue Oct 16 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.4.0-9
- move unversioned .so back to main package
- fix directory ownership
- fix scriplets
- add missing build requires

* Wed Oct 03 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-8
- Add disable-update-mimedb to configure flag and update files section

* Wed Oct 03 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-7
- Remove noreplace bit for schemas 
- Remove ownership of XMLnamespaces and aliases folders
- Remove desktop-file-utils from post and postun requires field
- Add mate-conf to post requires field

* Tue Oct 02 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-6
- Remove unnecessary explicit libexecdir configure flag, remove explicit requires field

* Tue Oct 02 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-5
- Fix spelling error on schema install.

* Sun Sep 30 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-4
- Update BR and remove about-me

* Wed Sep 26 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-3
- Add excludes to files section as per package review.

* Tue Sep 25 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-2
- Update files section as per review, update build requires.

* Sat Sep 01 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-1
- Initial build

